Package: AnalyzeFMRI
Version: 1.1-25
Date: 2025-07-11
Title: Functions for Analysis of fMRI Datasets Stored in the ANALYZE or
        'NIFTI' Format
Author: Pierre Lafaye De Micheaux [aut, cre],
  Jonathan L Marchini [aut],
  Cleve Moler [cph] (LAPACK/BLAS routines in src),
  Jack Dongarra [cph] (LAPACK/BLAS routines in src),
  Richard Hanson [cph] (LAPACK/BLAS routines in src),
  Sven Hammarling [cph] (LAPACK/BLAS routines in src),
  Jeremy Du Croz [cph] (LAPACK/BLAS routines in src)
Authors@R: c(person("Pierre", "Lafaye De Micheaux", role = c("aut", "cre"),
	             email = "lafaye@unsw.edu.au"),
             person("Jonathan L", "Marchini", role = c("aut"),
                    email = "jonathan.marchini@regeneron.com"),
	     person("Cleve", "Moler", role = "cph",
	            comment = "LAPACK/BLAS routines in src"),
	     person("Jack", "Dongarra", role = "cph",
	            comment = "LAPACK/BLAS routines in src"),
	     person("Richard", "Hanson", role = "cph",
	            comment = "LAPACK/BLAS routines in src"),
	     person("Sven", "Hammarling", role = "cph",
	            comment = "LAPACK/BLAS routines in src"),
	     person("Jeremy", "Du Croz", role = "cph",
	            comment = "LAPACK/BLAS routines in src"))
Maintainer: Pierre Lafaye De Micheaux <lafaye@unsw.edu.au>
Depends: R (>= 4.4.0), R.matlab, fastICA, tcltk
Suggests: tkrplot
Description: Functions for I/O, visualisation and analysis of functional Magnetic Resonance Imaging (fMRI) datasets stored in the ANALYZE or 'NIFTI' format. Note that the latest version of 'XQuartz' seems to be necessary under MacOS.
License: GPL (>= 2)
Packaged: 2025-07-23 01:43:41 UTC; lafaye
Copyright: For LAPACK/BLAS routines in src (Univ. of Tennessee, Univ.
        of California Berkeley, NAG Ltd., Courant Institute, Argonne
        National Lab, and Rice University).
NeedsCompilation: yes
Repository: CRAN
Date/Publication: 2025-07-24 12:50:12 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 05:32:33 UTC; unix
Archs: AnalyzeFMRI.so.dSYM
